#import <Foundation/Foundation.h>
#import <EDMessage/EDMessage.h>
#import "MessageExample.h"


@implementation MessageExample

- (EDInternetMessage *)createMessage
{
    // Create html part
	
	NSString *html = @"<p>This is the <b>HTML</b> version with an embedded image.<p><img src=\"cid:image-1\">";
    EDContentCoder *coder = [[[EDHTMLTextContentCoder alloc] initWithText:html] autorelease];
	EDMessagePart *htmltextPart = [coder messagePart];
	
	// Create image part
	
    NSData *imageData = [NSData dataWithContentsOfFile:@"edmessage.jpg"];
    NSAssert(imageData != nil, @"could not load image");
	
    coder = [[[EDMultimediaContentCoder alloc] initWithData:imageData filename:@"edmessage.jpg"] autorelease];
    EDMessagePart *imagePart = [coder messagePart];
	[imagePart addToHeaderFields:[EDObjectPair pairWithObjects:@"Content-ID":@"<image-1>"]];

	// Create a related multipart from html part and image part
	
    NSArray *htmlPartList = [NSMutableArray arrayWithObjects:htmltextPart, imagePart, nil];
    EDCompositeContentCoder *compositeCoder = [[[EDCompositeContentCoder alloc] initWithSubparts:htmlPartList] autorelease];
    EDMessagePart *htmlPart = [compositeCoder messagePartWithSubtype:@"related"];
	
    // Create plaintext part
	
	NSString *plaintext = @"This is the plain text alternative.";
    coder = [[[EDPlainTextContentCoder alloc] initWithText:plaintext] autorelease];
    EDMessagePart *plaintextPart = [coder messagePart];
	
	// Create alternative multipart from plaintext and html parts
	
    NSArray *textPartList = [NSMutableArray arrayWithObjects:plaintextPart, htmlPart, nil];
    compositeCoder = [[[EDCompositeContentCoder alloc] initWithSubparts:textPartList] autorelease];
    EDInternetMessage *message = [compositeCoder messageWithSubtype:@"alternative"];
	
    return message;
}


- (void)run
{
	// Create message. Please change the recipient.
	
	EDInternetMessage *message = [self createMessage];
    [message setSubject:@"Mail with embedded image"];
    [message setBody:@"steve@apple.com" forHeaderField:@"From"];
    [message setBody:@"erik@mulle-kybernetik.com" forHeaderField:@"To"];
	
	// Set up mail agent. Make sure to change the authentication info, or remove this if your
	// server does not require authentication.
	
	EDMailAgent *mailAgent = [EDMailAgent mailAgentForRelayHostWithName:@"mail.mulle-kybernetik.com" port:26];
	[mailAgent setUsesSecureConnections:YES];
	[mailAgent setAuthInfo:[NSDictionary dictionaryWithObjectsAndKeys:@"****", EDSMTPUserName, @"********", EDSMTPPassword, nil]];
	
	// Send message. If you have problems, create an empty file at "/tmp/EDMailAgent.log" and 
	// watch the contents. Don't forget to remove the file when you're done, though.
	
	[mailAgent sendMessage:message];
}

@end
